/**
 * Copyright (c) 2006-2012 EBMWebsourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.component.framework.api.exception;

import javax.jbi.JBIException;

/**
 * The generic CDK exception.
 * @author Christophe Hamerling - EBM WebSourcing
 */
public class PEtALSCDKException extends JBIException {

    /**
     * Serial UID
     */
    private static final long serialVersionUID = 1494074986698995541L;

    public PEtALSCDKException(String message, Throwable cause) {
        super(message, cause);
    }

    public PEtALSCDKException(String message) {
        super(message);
    }

    public PEtALSCDKException(Throwable cause) {
        super(cause);
    }

    /**
     * Meant to be used with {@link #addSuppressed(Throwable)}.
     * 
     * Either there is a cause, and it is meant to be thrown either way (and it is equivalent of throwing it directly)
     * 
     * Either there is no cause, and it will be thrown only if there is a suppressed exception.
     *
     */
    public void throwIfNeeded() throws PEtALSCDKException {
        if (this.getCause() == null && getSuppressed().length == 0) {
            return;
        }

        if (this.getCause() == null && getSuppressed().length == 1) {
            final Throwable e = getSuppressed()[0];
            if (e instanceof PEtALSCDKException) {
                throw (PEtALSCDKException) e;
            } else {
                final PEtALSCDKException newE = new PEtALSCDKException(getMessage(), e);
                newE.setStackTrace(getStackTrace());
                throw newE;
            }
        }

        throw this;
    }
}
