/**
 * Copyright (c) 2015-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.component.framework.api.util;

import static org.junit.Assert.assertEquals;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Properties;

import org.junit.Rule;
import org.junit.Test;
import org.junit.rules.TemporaryFolder;

import com.ebmwebsourcing.easycommons.properties.PropertiesException;

/**
 * Unit test of {@link PropertiesUtil}
 * 
 * @author Christophe DENEUX - Linagora
 *
 */
public class PropertiesUtilTest {

    @Rule
    public final TemporaryFolder tempFolder = new TemporaryFolder();

    @Test
    public void loadProperties() throws IOException, PropertiesException {

        final Properties expectedProperties = new Properties();
        final String expectedKey = "expectedKey";
        final String expectedValue = "expectedValue";
        expectedProperties.setProperty(expectedKey, expectedValue);
        final File propertiesFile = this.tempFolder.newFile();
        expectedProperties.store(new FileOutputStream(propertiesFile), "");

        // Load using a path 'null'
        final Properties propertiesNull = PropertiesUtil.loadProperties(null);
        assertEquals(0, propertiesNull.size());

        // Load using an absolute path
        final Properties propertiesFromAbsPath = PropertiesUtil.loadProperties(propertiesFile.getAbsolutePath());
        assertEquals(1, propertiesFromAbsPath.size());
        assertEquals(expectedValue, propertiesFromAbsPath.getProperty(expectedKey));

        // Load using an URL
        final Properties propertiesFromURL = PropertiesUtil.loadProperties(propertiesFile.toURI().toURL()
                .toExternalForm());
        assertEquals(1, propertiesFromURL.size());
        assertEquals(expectedValue, propertiesFromURL.getProperty(expectedKey));
    }

}
